---
name: Documentation Issue
about: Report an issue with our documentation to help improve SQLFluff
labels: documentation
---

_Use this template to report issues or suggest changes to our documentation on GitHub, on our [Documentation Website](https://docs.sqlfluff.com/) or inline help and error messages shown when running SQLFluff (please note non-documentation issues should be reported using the Bug template or the Enhancement template)._

## URL or Command Line Option with the issue being reported


## Issue/Suggested Improvement

